# SPDX-License-Identifier: BSD-3-Clause
# SPDX-FileCopyrightText: 2022 Z-Wave-Alliance <https://z-wavealliance.org/>
import xml.etree.ElementTree as ET
from jinja2 import Environment, FileSystemLoader, Template
import xmltodict
import os
from unidecode import unidecode
import argparse

def generate(root):
  template_paths = [
    root + 'templates/zwave/',
    root + 'templates/zw_manufacturers/'
  ]
  env = Environment(loader=FileSystemLoader(template_paths),extensions=['jinja2_strcase.StrcaseExtension'])
  
  with open(root + '/zwave.xml') as fd:
      zwave = xmltodict.parse(fd.read(),force_list=True)

  output_path = root + '/dist/'

  for file in os.listdir(template_paths[0]):
    if file.endswith('.jinja'):
      print('Processing ' + file + ' ...', end='')

      tmpl = env.get_template(file)

      if os.path.isdir(output_path) != True:
        os.makedirs(output_path)

      file_without_jinja = os.path.splitext(file)

      tmpl.stream(zwave = zwave).dump(output_path + file_without_jinja[0])

      print(' done.')

  with open(root + 'zw_manufacturers.xml') as fd:
    manufacturers = xmltodict.parse(unidecode(fd.read()),force_list=True)

  for file in os.listdir(template_paths[1]):
    if file.endswith('.jinja'):
      print('Processing ' + file + ' ...', end='')

      # tmpl = Template(f.read())
      tmpl = env.get_template(file)
      if os.path.isdir(output_path) != True:
        os.makedirs(output_path)

      file_without_jinja = os.path.splitext(file)

      tmpl.stream(manufacturers = manufacturers).dump(output_path + file_without_jinja[0])

      print(' done.')


def main():
  parser = argparse.ArgumentParser()
  
  parser.add_argument('--root', required=False)
  
  args = parser.parse_args()
  
  root = ''
  
  if args.root == None:
    # Root option is not set. Use current working directory.
    root = os.getcwd()
  else:
    root = args.root
  
  generate(root)
  
  
if __name__=="__main__": 
  main()
